# Vendorized Schemas

These are vendored versions of the schemas referred to by the hooks.
For the exact list of schemas here, see the repo root for hook config.

## Licenses

Most of the schemas in this directory are provided by SchemaStore. They are
therefore licensed under the SchemaStore license, included in this directory.
Additional licenses are provided for other sources as noted below.

### Azure Pipelines

The Azure pipelines schema is provided by Microsoft and is licensed under the
license for azure-pipelines-vscode.

### ReadTheDocs

The ReadTheDocs schema is provided by ReadTheDocs and licensed under the
license for readthedocs.org

### Renovate

The Renovate schema is provided by Renovate and licensed under the license for
renovatebot

### GitLab

The GitLab CI schema is provided by GitLab and licensed under the license for
the public gitlab repo. In particular, it falls under the "MIT Expat" portion
of the license for that repo.
